
# pygsuite
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://raw.githubusercontent.com/pygsuite/pygsuite/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/pygsuite.svg)](https://pypi.org/project/pygsuite/)
[![Python Versions](https://img.shields.io/pypi/pyversions/pygsuite.svg)](https://pypi.python.org/pypi/pygsuite)
[![Downloads](https://img.shields.io/badge/dynamic/json.svg?label=downloads&url=https%3A%2F%2Fpypistats.org%2Fapi%2Fpackages%2Fpygsuite%2Frecent&query=data.last_month&colorB=brightgreen&suffix=%2FMonth)](https://pypistats.org/packages/pygsuite)
[![Join the chat at https://gitter.im/pygsuite/community](https://badges.gitter.im/pygsuite/community.svg)](https://gitter.im/pygsuite/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

Pygsuite provides utilities for working with g-suite products such as docs, forms, sheets, and slides 
in an intuitive, pythonic, object-oriented way. TLDR; it makes the google APIs more fun to use. 

Base level goals is 100% support for all API objects, with an emphasis on type completion and IDE+autocomplete support.
Where helpful, additional higher level abstractions are provided to improve developer velocity. 

Typical use cases include personal or business process automation. 

Pygsuite supports the following:

- Sheets
- Slides
- Docs
- Forms

as well as providing a base level of Drive support for these 4 and beyond, such as for sharing and managing objects. 

## Install

`pygsuite` is [hosted on PyPI](https://pypi.org/project/pygsuite/), and is installable with [pip](https://pip.pypa.io/en/stable/):

```bash
$ pip install pygsuite
```

## Documentation

[Read the Docs](https://pygsuite.readthedocs.io/en/latest/)

## Contributing

`pygsuite` is an open source project, and community contributions are very welcome. Before contributing, please check out our [contribution page]() as part of our documentation.

